'use strict';

var postcss = require('postcss');
var unprefixed = postcss.vendor.unprefixed;

var _require = require('./decls'),
    rtlifyDecl = _require.rtlifyDecl;

var _require2 = require('./rules'),
    rtlifyRule = _require2.rtlifyRule;

var isKeyframeRule = function isKeyframeRule(rule) {
    return rule.type === 'atrule' && unprefixed(rule.name) === 'keyframes';
};

var isKeyframeAlreadyProcessed = function isKeyframeAlreadyProcessed(rule) {
    return !!rule.params.match(/-ltr$|-rtl$/);
};

var isKeyframeSymmetric = function isKeyframeSymmetric(rule) {
    return !rtlifyRule(rule);
};

var rtlifyKeyframe = function rtlifyKeyframe(rule) {
    var rtlRule = rule.cloneAfter({ params: rule.params + '-rtl' });
    rule.params += '-ltr';

    rtlRule.walkDecls(function (decl) {
        var rtl = rtlifyDecl(decl);
        decl.value = rtl ? rtl.value : decl.value;
    });
};

module.exports = {
    isKeyframeRule: isKeyframeRule,
    isKeyframeAlreadyProcessed: isKeyframeAlreadyProcessed,
    isKeyframeSymmetric: isKeyframeSymmetric,
    rtlifyKeyframe: rtlifyKeyframe
};